@@ -9,10 +9,16 @@
 import time
 
 from MoinMoin import wikiutil
-
+from MoinMoin.Page import Page
 
 def execute(pagename, request):
     """ set bookmarks (in time) for RecentChanges or delete them """
+    _ = request.getText
+    if not request.user.valid:
+        actname = __name__.split('.')[-1]
+        request.theme.add_msg(_("You must login to use this action: %(action)s.") % {"action": actname}, "error")
+        return Page(request, pagename).send_page()
+
     timestamp = request.form.get('time', [None])[0]
     if timestamp is not None:
         if timestamp == 'del':
