@@ -613,7 +613,7 @@ class convert_tree(visitor):
                 for i in listitem.childNodes:
                     if i.nodeType == Node.ELEMENT_NODE:
                         if i.localName == 'table':
-                            markup = " "
+                            markup = ""
             else:
                 markup = "* "
         elif name == 'dl':
@@ -682,6 +682,12 @@ class convert_tree(visitor):
         found = False
         need_indent = False
         pending = []
+
+        # If this is a empty list item, we just terminate the line
+        if node.childNodes.length == 0:
+            self.text.append(self.new_line)
+            return
+
         for i in node.childNodes:
             name = i.localName
 
