@@ -10,6 +10,9 @@
 
 import re, zipfile
 
+from MoinMoin import log
+logging = log.getLogger(__name__)
+
 rx_stripxml = re.compile("<[^>]*?>", re.DOTALL|re.MULTILINE)
 
 def execute(indexobj, filename):
@@ -18,8 +21,8 @@ def execute(indexobj, filename):
         data = zf.read("content.xml")
         zf.close()
         data = " ".join(rx_stripxml.sub(" ", data).split())
-    except RuntimeError, err:
-        indexobj.request.log(str(err))
+    except (zipfile.BadZipfile, RuntimeError), err:
+        logging.error("%s [%s]" % (str(err), filename))
         data = ""
     return data.decode('utf-8')
 
