@@ -433,11 +433,11 @@ class Parser:
             return self.attachment(words, pretty_url=1)
 
         if wikiutil.isPicture(words[1]) and re.match(self.url_rule, words[1]):
-            return (self.formatter.url(1, words[0], css='external', do_escape=0) +
+            return (self.formatter.url(1, words[0], css='external') +
                     self.formatter.image(title=words[0], alt=words[0], src=words[1]) +
                     self.formatter.url(0))
         else:
-            return (self.formatter.url(1, words[0], css=scheme, do_escape=0) +
+            return (self.formatter.url(1, words[0], css=scheme) +
                     self.formatter.text(words[1]) +
                     self.formatter.url(0))
 
@@ -697,7 +697,6 @@ class Parser:
         attr, msg = wikiutil.parseAttributes(self.request, attrdef, '>', table_extension)
         if msg:
             msg = '<strong class="highlight">%s</strong>' % msg
-        #self.request.log("parseAttributes returned %r" % attr)
         return attr, msg
 
     def _tableZ_repl(self, word):
@@ -749,7 +748,7 @@ class Parser:
 
     def _heading_repl(self, word):
         """Handle section headings."""
-        import sha
+        from MoinMoin.support.python_compatibility import hash_new
 
         h = word.strip()
         level = 1
@@ -769,7 +768,7 @@ class Parser:
         if self.titles[pntt] > 1:
             unique_id = '-%d' % self.titles[pntt]
         result = self._closeP()
-        result += self.formatter.heading(1, depth, id="head-"+sha.new(pntt.encode(config.charset)).hexdigest()+unique_id)
+        result += self.formatter.heading(1, depth, id="head-"+hash_new('sha1', pntt.encode(config.charset)).hexdigest()+unique_id)
 
         return (result + self.formatter.text(title_text) +
                 self.formatter.heading(0, depth))
