@@ -36,7 +36,7 @@
 #       CONTENT_LENGTH and abort the update if the two numbers are not equal.
 
 import logging
-LOGLEVEL = logging.DEBUG # logging.NOTSET to completely switch it off
+log = logging.getLogger(__name__)
 
 import os
 import sys
@@ -101,7 +101,7 @@ FCGI_EndRequestBody = "!IB3x"
 
 
 def log(s):
-    logging.log(LOGLEVEL, 'thfcgi: %s' % s)
+    logging.debug(s)
 
 class SocketErrorOnWrite:
     """Is raised if a write fails in the socket code."""
