@@ -209,7 +209,7 @@ class ThemeBase:
         """
         if self.request.cfg.show_interwiki:
             page = wikiutil.getFrontPage(self.request)
-            text = self.request.cfg.interwikiname or 'Self'
+            text = self.request.cfg.interwikiname or u'Self'
             link = page.link_to(self.request, text=text, rel='nofollow')
             html = u'<div id="interwiki"><span>%s</span></div>' % link
         else:
@@ -672,8 +672,8 @@ class ThemeBase:
         cfg_css = [self._stylesheet_link(False, *stylesheet) for stylesheet in request.cfg.stylesheets]
 
         msie_css = """
-<!-- css only for MSIE browsers -->
-<!--[if IE]>
+<!-- css only for MS IE6/IE7 browsers -->
+<!--[if lt IE 8]>
    %s
 <![endif]-->
 """ % self._stylesheet_link(True, 'all', 'msie')
