@@ -15,7 +15,8 @@ class DataBrowserWidget(base.Widget):
         _ = request.getText
         base.Widget.__init__(self, request, **kw)
         self.data = None
-        self.data_id = 'dbw.'
+        self.unqual_data_id = 'dbw.'
+        self.data_id = request.formatter.qualify_id(self.unqual_data_id)
         # prefixed with __ are untranslated and to be used in the JS
         self._all = _('[all]')
         self.__all = '[all]'
@@ -37,7 +38,8 @@ class DataBrowserWidget(base.Widget):
         """
         self.data = dataset
         if dataset.data_id:
-            self.data_id = 'dbw.%s.' % dataset.data_id
+            self.unqual_data_id = 'dbw.%s.' % dataset.data_id
+            self.data_id = self.request.formatter.qualify_id(self.unqual_data_id)
 
     def _name(self, elem):
         """ return name tag for a HTML element
@@ -87,10 +89,13 @@ class DataBrowserWidget(base.Widget):
         del unique[0]
         unique.sort()
         result = [self._makeoption(item, item == value) for item in unique]
-        common = [None, None, None]
-        common[0] = self._makeoption(self._all, value == self.__all, self.__all)
-        common[1] = self._makeoption(self._empty, value == self.__empty, self.__empty)
-        common[2] = self._makeoption(self._notempty, value == self.__notempty, self.__notempty)
+        common = []
+        common.append(self._makeoption(self._all, value == self.__all, self.__all))
+        if '' in unique:
+            common.extend([
+                self._makeoption(self._empty, value == self.__empty, self.__empty),
+                self._makeoption(self._notempty, value == self.__notempty, self.__notempty),
+            ])
         return '\n'.join(common + result)
 
     def _format(self, formatter=None, method=None):
@@ -115,7 +120,7 @@ class DataBrowserWidget(base.Widget):
         if havefilters:
             result.append(fmt.rawHTML('<input type="submit" value="%s" %s>' % (self._filter, self._name('submit'))))
 
-        result.append(fmt.table(1, id='%stable' % self.data_id))
+        result.append(fmt.table(1, id='%stable' % self.unqual_data_id))
 
         # add header line
         if self._show_header:
@@ -124,7 +129,8 @@ class DataBrowserWidget(base.Widget):
                 col = self.data.columns[idx]
                 if col.hidden:
                     continue
-                result.append(fmt.table_cell(1))
+                cell_attrs = {'class': 'hcolumn%d' % idx}
+                result.append(fmt.table_cell(1, cell_attrs))
                 result.append(fmt.strong(1))
                 result.append(col.label or col.name)
                 result.append(fmt.strong(0))
@@ -178,11 +184,12 @@ class DataBrowserWidget(base.Widget):
                 for idx in range(len(row)):
                     if self.data.columns[idx].hidden:
                         continue
+                    cell_attrs = {'class': 'column%d' % idx}
                     if isinstance(row[idx], tuple):
-                        result.append(fmt.table_cell(1, abbr=unicode(row[idx][1])))
+                        result.append(fmt.table_cell(1, cell_attrs, abbr=unicode(row[idx][1])))
                         result.append(unicode(row[idx][0]))
                     else:
-                        result.append(fmt.table_cell(1))
+                        result.append(fmt.table_cell(1, cell_attrs))
                         result.append(unicode(row[idx]))
                     result.append(fmt.table_cell(0))
                 result.append(fmt.table_row(0))
