@@ -166,7 +166,7 @@ class MoinRemoteWiki(RemoteWiki):
         self.verbose = verbose
         _ = self.request.getText
 
-        wikitag, wikiurl, wikitail, wikitag_bad = wikiutil.resolve_wiki(self.request, '%s:""' % (interwikiname, ))
+        wikitag, wikiurl, wikitail, wikitag_bad = wikiutil.resolve_interwiki(self.request, interwikiname, '')
         self.wiki_url = wikiutil.mapURL(self.request, wikiurl)
         self.valid = not wikitag_bad
         self.xmlrpc_url = self.wiki_url + "?action=xmlrpc2"
@@ -179,7 +179,7 @@ class MoinRemoteWiki(RemoteWiki):
         try:
             iw_list = self.connection.interwikiName()
         except socket.error:
-            raise UnsupportedWikiException(_("The wiki is currently not reachable.", formatted=False))
+            raise UnsupportedWikiException(_("The wiki is currently not reachable."))
         except xmlrpclib.Fault, err:
             raise UnsupportedWikiException("xmlrpclib.Fault: %s" % str(err))
 
@@ -188,7 +188,7 @@ class MoinRemoteWiki(RemoteWiki):
             if token:
                 self.token = token
             else:
-                raise NotAllowedException(_("Invalid username or password.", formatted=False))
+                raise NotAllowedException(_("Invalid username or password."))
         else:
             self.token = None
 
@@ -197,7 +197,7 @@ class MoinRemoteWiki(RemoteWiki):
         self.is_anonymous = remote_interwikiname is None
         if not self.is_anonymous and interwikiname != remote_interwikiname:
             raise UnsupportedWikiException(_("The remote wiki uses a different InterWiki name (%(remotename)s)"
-                                             " internally than you specified (%(localname)s).", formatted=False) % {
+                                             " internally than you specified (%(localname)s).") % {
                 "remotename": wikiutil.escape(remote_interwikiname), "localname": wikiutil.escape(interwikiname)})
 
         if self.is_anonymous:
@@ -259,7 +259,7 @@ class MoinRemoteWiki(RemoteWiki):
             return [("applyAuthToken", (self.token, ))]
         return []
 
-    def destroy(self):
+    def delete_auth_token(self):
         if self.token:
             self.connection.deleteAuthToken(self.token)
             self.token = None
@@ -321,8 +321,6 @@ class MoinLocalWiki(RemoteWiki):
         normalised_name = normalise_pagename(page_name, self.prefix)
         if normalised_name is None:
             return None
-        if not self.request.user.may.write(normalised_name):
-            return None
         page = Page(self.request, page_name)
         revno = page.get_real_rev()
         if revno == 99999999: # I love sane in-band signalling
