@@ -6,6 +6,9 @@
     @license: GNU GPL, see COPYING for details.
 """
 
+from MoinMoin import log
+logging = log.getLogger(__name__)
+
 from MoinMoin.mail import mailimport
 
 def execute(xmlrpcobj, secret, mail):
@@ -13,16 +16,13 @@ def execute(xmlrpcobj, secret, mail):
     secret = xmlrpcobj._instr(secret)
     mail = str(mail)
 
-    if not request.cfg.mail_import_secret:
-        return u"No password set"
-
-    if request.cfg.mail_import_secret != secret:
+    if request.cfg.secrets['xmlrpc/ProcessMail'] != secret:
         return u"Invalid password"
 
     try:
         mailimport.import_mail_from_string(request, mail)
     except mailimport.ProcessingError, e:
         err = u"An error occured while processing the message: " + str(e.args)
-        request.log(err)
+        logging.error(err)
         return xmlrpcobj._outstr(err)
     return xmlrpcobj._outstr(u"OK")
