@@ -2,9 +2,6 @@
 """
     MoinMoin - Wiki XMLRPC v1 and v2 Interface + plugin extensions
 
-    If you want to use wikirpc function "putPage", read the comments in
-    xmlrpc_putPage or it won't work!
-    
     Parts of this code are based on Juergen Hermann's wikirpc.py,
     Les Orchard's "xmlrpc.cgi" and further work by Gustavo Niemeyer.
 
@@ -20,7 +17,7 @@
     when really necessary (like for transferring binary files like
     attachments maybe).
 
-    @copyright: 2003-2007 MoinMoin:ThomasWaldmann,
+    @copyright: 2003-2008 MoinMoin:ThomasWaldmann,
                 2004-2006 MoinMoin:AlexanderSchremmer
     @license: GNU GPL, see COPYING for details
 """
@@ -29,16 +26,32 @@ from MoinMoin.util import pysupport
 modules = pysupport.getPackageModules(__file__)
 
 import os, sys, time, xmlrpclib
-from random import randint
+
+from MoinMoin import log
+logging = log.getLogger(__name__)
 
 from MoinMoin import config, user, wikiutil
 from MoinMoin.Page import Page
 from MoinMoin.PageEditor import PageEditor
 from MoinMoin.logfile import editlog
 from MoinMoin.action import AttachFile
-from MoinMoin.auth import SessionData
+from MoinMoin import caching
+from MoinMoin import session
 
-_debug = 0
+
+class XmlRpcAuthTokenIDHandler(session.SessionIDHandler):
+    def __init__(self, token=None):
+        session.SessionIDHandler.__init__(self)
+        self.token = token
+
+    def get(self, request):
+        return self.token
+
+    def set(self, request, session_id, expires):
+        self.token = session_id
+
+
+logging_tearline = '- XMLRPC %s ' + '-' * 40
 
 class XmlRpcBase:
     """ XMLRPC base class with common functionality of wiki xmlrpc v1 and v2 """
@@ -52,12 +65,12 @@ class XmlRpcBase:
         self.cfg = request.cfg
 
     #############################################################################
-    ### Helper functions           
+    ### Helper functions
     #############################################################################
 
     def _instr(self, text):
         """ Convert inbound string.
-        
+
         @param text: the text to convert (encoded str or unicode)
         @rtype: unicode
         @return: text as unicode
@@ -75,7 +88,7 @@ class XmlRpcBase:
 
     def _inlob(self, text):
         """ Convert inbound base64-encoded utf-8 to Large OBject.
-        
+
         @param text: the text to convert
         @rtype: unicode
         @return: text
@@ -86,7 +99,7 @@ class XmlRpcBase:
 
     def _outlob(self, text):
         """ Convert outbound Large OBject to base64-encoded utf-8.
-        
+
         @param text: the text, either unicode or utf-8 string
         @rtype: str
         @return: xmlrpc Binary object
@@ -100,7 +113,7 @@ class XmlRpcBase:
 
     def _dump_exc(self):
         """ Convert an exception to a string.
-        
+
         @rtype: str
         @return: traceback as string
         """
@@ -119,26 +132,39 @@ class XmlRpcBase:
                 # we do not handle xmlrpc v1 and v2 differently
                 response = xmlrpclib.Fault(1, "This moin wiki does not allow xmlrpc method calls.")
             else:
-                data = self.request.read()
-                params, method = xmlrpclib.loads(data)
+                data = self.request.read(self.request.content_length)
 
-                if _debug:
-                    sys.stderr.write('- XMLRPC ' + '-' * 70 + '\n')
-                    sys.stderr.write('%s(%s)\n\n' % (method, repr(params)))
+                try:
+                    params, method = xmlrpclib.loads(data)
+                except:
+                    # if anything goes wrong here, we want to see the raw data:
+                    logging.debug("Length of raw data: %d bytes" % len(data))
+                    logging.debug(logging_tearline % 'request raw data begin')
+                    logging.debug('%r' % data)
+                    logging.debug(logging_tearline % 'request raw data end')
+                    raise
+
+                logging.debug(logging_tearline % 'request parsed data begin')
+                logging.debug('%s(%r)' % (method, params))
+                logging.debug(logging_tearline % 'request parsed data end')
 
                 response = self.dispatch(method, params)
         except:
-            # report exception back to server
+            logging.exception("An exception occurred (this is also sent as fault response to the client):")
+            # report exception back to client
             response = xmlrpclib.dumps(xmlrpclib.Fault(1, self._dump_exc()))
         else:
+            logging.debug(logging_tearline % 'response begin')
+            logging.debug(response)
+            logging.debug(logging_tearline % 'response end')
+
             if isinstance(response, xmlrpclib.Fault):
                 response = xmlrpclib.dumps(response)
             else:
                 # wrap response in a singleton tuple
-                response = (response,)
-
+                response = (response, )
                 # serialize it
-                response = xmlrpclib.dumps(response, methodresponse=1)
+                response = xmlrpclib.dumps(response, methodresponse=1, allow_none=True)
 
         self.request.emit_http_headers([
             "Content-Type: text/xml; charset=utf-8",
@@ -146,10 +172,6 @@ class XmlRpcBase:
         ])
         self.request.write(response)
 
-        if _debug:
-            sys.stderr.write('- XMLRPC ' + '-' * 70 + '\n')
-            sys.stderr.write(response + '\n\n')
-
     def dispatch(self, method, params):
         """ call dispatcher - for method==xxx it either locates a method called
             xmlrpc_xxx or loads a plugin from plugin/xmlrpc/xxx.py
@@ -180,6 +202,9 @@ class XmlRpcBase:
     def noSuchPageFault(self):
         return xmlrpclib.Fault(1, "No such page was found.")
 
+    def noLogEntryFault(self):
+        return xmlrpclib.Fault(1, "No log entry was found.")
+
     #############################################################################
     ### System methods
     #############################################################################
@@ -204,7 +229,7 @@ class XmlRpcBase:
                 # XXX A marshalling error in any response will fail the entire
                 # multicall. If someone cares they should fix this.
                 result = self.dispatch(method_name, params)
-                
+
                 if not isinstance(result, xmlrpclib.Fault):
                     results.append([result])
                 else:
@@ -217,7 +242,7 @@ class XmlRpcBase:
                     {'faultCode': 1,
                      'faultString': "%s:%s" % (sys.exc_type, sys.exc_value)}
                     )
-                
+
         return results
 
     #############################################################################
@@ -358,7 +383,7 @@ class XmlRpcBase:
 
     def xmlrpc_getPageInfoVersion(self, pagename, rev):
         """ Return page information for specific revision
-        
+
         @param pagename: the name of the page (utf-8)
         @param rev: revision to get info about (int)
         @rtype: dict
@@ -386,8 +411,11 @@ class XmlRpcBase:
             return self.noSuchPageFault()
 
         # Get page info
-        last_edit = page.last_edit(self.request)
-        mtime = wikiutil.version2timestamp(long(last_edit['timestamp'])) # must be long for py 2.2.x
+        edit_info = page.edit_info()
+        if not edit_info:
+            return self.noLogEntryFault()
+
+        mtime = wikiutil.version2timestamp(long(edit_info['timestamp'])) # must be long for py 2.2.x
         gmtuple = tuple(time.gmtime(mtime))
 
         version = rev # our new rev numbers: 1,2,3,4,....
@@ -406,7 +434,7 @@ class XmlRpcBase:
         return {
             'name': self._outstr(page.page_name),
             'lastModified': xmlrpclib.DateTime(gmtuple),
-            'author': self._outstr(last_edit['editor']),
+            'author': self._outstr(edit_info['editor']),
             'version': version,
             }
 
@@ -416,7 +444,7 @@ class XmlRpcBase:
 
     def xmlrpc_getPageVersion(self, pagename, rev):
         """ Get raw text from specific revision of pagename
-        
+
         @param pagename: pagename (utf-8)
         @param rev: revision number (int)
         @rtype: str
@@ -449,7 +477,7 @@ class XmlRpcBase:
 
     def xmlrpc_getPageHTMLVersion(self, pagename, rev):
         """ Get HTML of from specific revision of pagename
-        
+
         @param pagename: the page name (utf-8)
         @param rev: revision number (int)
         @rtype: str
@@ -523,8 +551,6 @@ class XmlRpcBase:
         # check ACLs
         if not self.request.user.may.write(pagename):
             return xmlrpclib.Fault(1, "You are not allowed to edit this page")
-        
-        # =================================================================
 
         page = PageEditor(self.request, pagename)
         try:
@@ -534,8 +560,7 @@ class XmlRpcBase:
                 newtext = self._inlob(pagetext)
             msg = page.saveText(newtext, 0)
         except page.SaveError, msg:
-            if _debug:
-                sys.stderr.write("Msg: %s\n" % msg)
+            logging.error("SaveError: %s" % msg)
             return xmlrpclib.Fault(1, "%s" % msg)
 
         # Update pagelinks cache
@@ -543,6 +568,30 @@ class XmlRpcBase:
 
         return xmlrpclib.Boolean(1)
 
+    def xmlrpc_revertPage(self, pagename, revision):
+        """Revert a page to previous revision
+
+        This is mainly intended to be used by the jabber bot.
+
+        @param pagename: the page name (unicode or utf-8)
+        @param revision: revision to revert to
+        @rtype bool
+        @return true on success
+
+        """
+        if not self.request.user.may.write(pagename):
+            return xmlrpclib.Fault(1, "You are not allowed to edit this page")
+
+        rev = int(self._instr(revision))
+        editor = PageEditor(self.request, pagename)
+
+        try:
+            editor.revertPage(rev)
+        except PageEditor.SaveError, error:
+            return xmlrpclib.Fault(1, "Revert failed: %s" % (str(error), ))
+
+        return xmlrpclib.Boolean(1)
+
     def xmlrpc_searchPages(self, query_string):
         """ Searches pages for query_string.
             Returns a list of tuples (foundpagename, context)
@@ -555,6 +604,36 @@ class XmlRpcBase:
                  self._outstr(results.formatContext(hit, 180, 1)))
                 for hit in results.hits]
 
+    def xmlrpc_searchPagesEx(self, query_string, search_type, length, case, mtime, regexp):
+        """ Searches pages for query_string - extended version for compatibility
+
+        This function, in contrary to searchPages(), doesn't return HTML-formatted data.
+
+        @param query_string: term to search for
+        @param search_type: "text" or "title" search
+        @param length: length of context preview (in characters)
+        @param case: should the search be case sensitive?
+        @param mtime: only output pages modified after mtime
+        @param regexp: should the query_string be treates as a regular expression?
+        @return: (page name, context preview, page url)
+
+        """
+        from MoinMoin import search
+        from MoinMoin.formatter.text_plain import Formatter
+
+        kwargs = {"sort": "page_name", "case": case, "regex": regexp}
+        if search_type == "title":
+            kwargs["titlesearch"] = True
+
+        results = search.searchPages(self.request, query_string, **kwargs)
+        results.formatter = Formatter(self.request)
+        results.request = self.request
+
+        return [(self._outstr(hit.page_name),
+                 self._outstr(results.formatContext(hit, length, 1)),
+                 self.request.getQualifiedURL(hit.page.url(self.request, {})))
+                for hit in results.hits]
+
     def xmlrpc_getMoinVersion(self):
         """ Returns a tuple of the MoinMoin version:
             (project, release, revision)
@@ -562,6 +641,7 @@ class XmlRpcBase:
         from MoinMoin import version
         return (version.project, version.release, version.revision)
 
+
     # user profile data transfer
 
     def xmlrpc_getUserProfile(self):
@@ -577,30 +657,58 @@ class XmlRpcBase:
             userdata = dict(u.persistent_items())
         return userdata
 
-    # authorization methods
+    def xmlrpc_getUserLanguageByJID(self, jid):
+        """ Returns user's language given his/her Jabber ID
 
-    def _generate_auth_token(self, usr):
-        """Generate a token that can be used to authorize next requests"""
-        token = ''
-        chars = 'abcdefghijklmnopqrstuvwxyz0123456789'
-        for i in range(32):
-            token += chars[randint(0, len(chars)-1)]
-        return token
+        It makes no sense to consider this a secret, right? Therefore
+        an authentication token is not required. We return a default
+        of "en" if user is not found.
+
+        TODO: surge protection? Do we fear account enumeration?
+        """
+        retval = "en"
+        u = user.get_by_jabber_id(self.request, jid)
+        if u:
+            retval = u.language
+
+        return retval
+
+    # authorization methods
 
     def xmlrpc_getAuthToken(self, username, password, *args):
         """ Returns a token which can be used for authentication
             in other XMLRPC calls. If the token is empty, the username
-            or the password were wrong. """
+            or the password were wrong.
+        """
+        id_handler = XmlRpcAuthTokenIDHandler()
+
+        u = self.request.cfg.session_handler.start(self.request, id_handler)
+        u = self.request.handle_auth(u, username=username,
+                                     password=password, login=True)
+
+        self.request.cfg.session_handler.after_auth(self.request, id_handler, u)
 
-        u = self.request.get_user_default_None(name=username,
-                                               password=password,
-                                               login=True)
         if u and u.valid:
-            token = self._generate_auth_token(u)
-            session = SessionData(self.request, token,
-                                  time.time() + 1800)
-            session['xmlrpc-uid'] = u.id
-            return token
+            return id_handler.token
+        else:
+            return ""
+
+    def xmlrpc_getJabberAuthToken(self, jid, secret):
+        """Returns a token which can be used for authentication.
+
+        This token can be used in other XMLRPC calls. Generation of
+        token depends on user's JID and a secret shared between wiki
+        and Jabber bot.
+
+        @param jid: a bare Jabber ID
+        """
+        if self.cfg.secrets['jabberbot'] != secret:
+            return ""
+
+        u = self.request.handle_jid_auth(jid)
+
+        if u and u.valid:
+            return self._generate_auth_token(u)
         else:
             return ""
 
@@ -609,21 +717,13 @@ class XmlRpcBase:
         if not auth_token:
             return xmlrpclib.Fault("INVALID", "Empty token.")
 
-        session = SessionData(self.request, auth_token, 0)
+        id_handler = XmlRpcAuthTokenIDHandler(auth_token)
 
-        if session['expires'] < time.time():
-            session.delete()
-            return xmlrpclib.Fault("INVALID", "Expired token.")
-
-        uid = session.get("xmlrpc-uid")
-        if not uid:
-            session.delete()
-            return xmlrpclib.Fault("INVALID", "Invalid token.")
-
-        u = user.User(self.request, id=uid, auth_method='xmlrpc_applytoken')
-        if u.valid:
+        u = self.request.cfg.session_handler.start(self.request, id_handler)
+        u = self.request.handle_auth(u)
+        self.request.cfg.session_handler.after_auth(self.request, id_handler, u)
+        if u and u.valid:
             self.request.user = u
-            self.request.session = session
             return "SUCCESS"
         else:
             return xmlrpclib.Fault("INVALID", "Invalid token.")
@@ -631,8 +731,14 @@ class XmlRpcBase:
 
     def xmlrpc_deleteAuthToken(self, auth_token):
         """ Delete the given auth token. """
-        session = SessionData(self.request, auth_token, 0)
-        session.delete()
+        id_handler = XmlRpcAuthTokenIDHandler(auth_token)
+
+        u = self.request.cfg.session_handler.start(self.request, id_handler)
+        u = self.request.handle_auth(u)
+        self.request.cfg.session_handler.after_auth(self.request, id_handler, u)
+
+        self.request.session.delete()
+
         return "SUCCESS"
 
 
@@ -830,7 +936,7 @@ class XmlRpcBase:
     def xmlrpc_listAttachments(self, pagename):
         """ Get all attachments associated with pagename
         Deprecated.
-        
+
         @param pagename: pagename (utf-8)
         @rtype: list
         @return: a list of utf-8 attachment names
@@ -845,7 +951,7 @@ class XmlRpcBase:
 
     def xmlrpc_getAttachment(self, pagename, attachname):
         """ Get attachname associated with pagename
-        
+
         @param pagename: pagename (utf-8)
         @param attachname: attachment name (utf-8)
         @rtype base64
@@ -864,7 +970,7 @@ class XmlRpcBase:
 
     def xmlrpc_putAttachment(self, pagename, attachname, data):
         """ Set attachname associated with pagename to data
-        
+
         @param pagename: pagename (utf-8)
         @param attachname: attachment name (utf-8)
         @param data: file data (base64)
@@ -875,6 +981,8 @@ class XmlRpcBase:
         # User may read page?
         if not self.request.user.may.read(pagename):
             return self.notAllowedFault()
+
+        # also check ACLs
         if not self.request.user.may.write(pagename):
             return xmlrpclib.Fault(1, "You are not allowed to edit this page")
 
@@ -889,6 +997,15 @@ class XmlRpcBase:
     # XXX END WARNING XXX
 
 
+    def xmlrpc_getBotTranslations(self):
+        """ Return translations to be used by notification bot
+
+        @return: a dict (indexed by language) of dicts of translated strings (indexed by original ones)
+        """
+        from MoinMoin.i18n import bot_translations
+        return bot_translations(self.request)
+
+
 class XmlRpc1(XmlRpcBase):
 
     def __init__(self, request):
